###################
Example Plugin Docs
###################

.. add the plugin module to the module index

.. py:module:: cobald_hep_plugins.example
    :synopsis: an example plugin

This is an example documentation for an example plugin.

Documentation uses reStructured Text (ReST) for the `Sphinx`_
documentation processor.
This allows you to write and format text,
refer to other code or packages‚ and
use a multitude of directives and plugins.
Note that you are not restricted to one document --
just create and link to another document.

Classes and Function
####################

While you should focus on users of the plugin,
it can be useful to document the key classes and functions as well.

Document classes and functions either
manually using `.. py:function::`/`.. py:class::`, or
automatically via `.. autoclass::`/`.. autofunction::` (sphinx autodoc).

.. autoclass:: DemandScale

.. _`Sphinx`: https://www.sphinx-doc.org/
